# Wordle Answer

This python package allows you to get today, yesterday and tomorrow's Wordle answer!

## Code Example

```
import wordleanswer

todaysAnswer = wordleanswer.getAnswer()
yesterdaysAnswer = wordleanswer.getYesterdayAnswer()
tomorrowsAnswer = wordleanswer.getTomorrowAnswer()
print(f"Todays's Answer: {todaysAnswer})
print(f"Yesterday's Answer: {yesterdaysAnswer})
print(f"Tomorrow's Answer: {tomorrowsAnswer})
```

This will return today, yesterday, and tomorrow's answer.